==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.assetequipment_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _NonDependentParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/AssetEquipment_001", "NonDependentParents");
    private final static QName _NoParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/AssetEquipment_001", "NoParents");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.assetequipment_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AssetEquipment }
     * 
     */
    public AssetEquipment createAssetEquipment() {
        return new AssetEquipment();
    }

    /**
     * Create an instance of {@link EquipmentBase }
     * 
     */
    public EquipmentBase createEquipmentBase() {
        return new EquipmentBase();
    }

    /**
     * Create an instance of {@link ChildAsset }
     * 
     */
    public ChildAsset createChildAsset() {
        return new ChildAsset();
    }

    /**
     * Create an instance of {@link ManufacturerInfo }
     * 
     */
    public ManufacturerInfo createManufacturerInfo() {
        return new ManufacturerInfo();
    }

    /**
     * Create an instance of {@link PartAssociation }
     * 
     */
    public PartAssociation createPartAssociation() {
        return new PartAssociation();
    }

    /**
     * Create an instance of {@link AssetEquipment.DORMANT }
     * 
     */
    public AssetEquipment.DORMANT createAssetEquipmentDORMANT() {
        return new AssetEquipment.DORMANT();
    }

    /**
     * Create an instance of {@link FleetVehicleInfo }
     * 
     */
    public FleetVehicleInfo createFleetVehicleInfo() {
        return new FleetVehicleInfo();
    }

    /**
     * Create an instance of {@link AssetEquipment.PurchaseOrderInfo }
     * 
     */
    public AssetEquipment.PurchaseOrderInfo createAssetEquipmentPurchaseOrderInfo() {
        return new AssetEquipment.PurchaseOrderInfo();
    }

    /**
     * Create an instance of {@link Variables }
     * 
     */
    public Variables createVariables() {
        return new Variables();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link AssetParentHierarchy }
     * 
     */
    public AssetParentHierarchy createAssetParentHierarchy() {
        return new AssetParentHierarchy();
    }

    /**
     * Create an instance of {@link AssetDependency }
     * 
     */
    public AssetDependency createAssetDependency() {
        return new AssetDependency();
    }

    /**
     * Create an instance of {@link PositionDependency }
     * 
     */
    public PositionDependency createPositionDependency() {
        return new PositionDependency();
    }

    /**
     * Create an instance of {@link PrimarySystemDependency }
     * 
     */
    public PrimarySystemDependency createPrimarySystemDependency() {
        return new PrimarySystemDependency();
    }

    /**
     * Create an instance of {@link SystemDependency }
     * 
     */
    public SystemDependency createSystemDependency() {
        return new SystemDependency();
    }

    /**
     * Create an instance of {@link LocationDependency }
     * 
     */
    public LocationDependency createLocationDependency() {
        return new LocationDependency();
    }

    /**
     * Create an instance of {@link NonDependentParents_Type }
     * 
     */
    public NonDependentParents_Type createNonDependentParents_Type() {
        return new NonDependentParents_Type();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link FacilityConditionIndex }
     * 
     */
    public FacilityConditionIndex createFacilityConditionIndex() {
        return new FacilityConditionIndex();
    }

    /**
     * Create an instance of {@link EnergyPerformance }
     * 
     */
    public EnergyPerformance createEnergyPerformance() {
        return new EnergyPerformance();
    }

    /**
     * Create an instance of {@link EquipmentHospitalityFacility }
     * 
     */
    public EquipmentHospitalityFacility createEquipmentHospitalityFacility() {
        return new EquipmentHospitalityFacility();
    }

    /**
     * Create an instance of {@link AssetChildHierarchy }
     * 
     */
    public AssetChildHierarchy createAssetChildHierarchy() {
        return new AssetChildHierarchy();
    }

    /**
     * Create an instance of {@link EquipmentCore }
     * 
     */
    public EquipmentCore createEquipmentCore() {
        return new EquipmentCore();
    }

    /**
     * Create an instance of {@link EquipmentHealthcareAsset }
     * 
     */
    public EquipmentHealthcareAsset createEquipmentHealthcareAsset() {
        return new EquipmentHealthcareAsset();
    }

    /**
     * Create an instance of {@link EquipmentHospitalityVehicle }
     * 
     */
    public EquipmentHospitalityVehicle createEquipmentHospitalityVehicle() {
        return new EquipmentHospitalityVehicle();
    }

    /**
     * Create an instance of {@link AllEquipment }
     * 
     */
    public AllEquipment createAllEquipment() {
        return new AllEquipment();
    }

    /**
     * Create an instance of {@link EquipmentBase.DORMANT }
     * 
     */
    public EquipmentBase.DORMANT createEquipmentBaseDORMANT() {
        return new EquipmentBase.DORMANT();
    }

    /**
     * Create an instance of {@link EquipmentBase.PurchaseOrderInfo }
     * 
     */
    public EquipmentBase.PurchaseOrderInfo createEquipmentBasePurchaseOrderInfo() {
        return new EquipmentBase.PurchaseOrderInfo();
    }

    /**
     * Create an instance of {@link EquipmentHealthcareSystem }
     * 
     */
    public EquipmentHealthcareSystem createEquipmentHealthcareSystem() {
        return new EquipmentHealthcareSystem();
    }

    /**
     * Create an instance of {@link EquipmentHealthcareProperty }
     * 
     */
    public EquipmentHealthcareProperty createEquipmentHealthcareProperty() {
        return new EquipmentHealthcareProperty();
    }

    /**
     * Create an instance of {@link EquipmentHospitalityRoom }
     * 
     */
    public EquipmentHospitalityRoom createEquipmentHospitalityRoom() {
        return new EquipmentHospitalityRoom();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link NonDependentParents_Type }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/AssetEquipment_001", name = "NonDependentParents")
    public JAXBElement<NonDependentParents_Type> createNonDependentParents(NonDependentParents_Type value) {
        return new JAXBElement<NonDependentParents_Type>(_NonDependentParents_QNAME, NonDependentParents_Type.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/AssetEquipment_001", name = "NoParents")
    public JAXBElement<String> createNoParents(String value) {
        return new JAXBElement<String>(_NoParents_QNAME, String.class, null, value);
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.assetequipment_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _NonDependentParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/AssetEquipment_001", "NonDependentParents");
    private final static QName _NoParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/AssetEquipment_001", "NoParents");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.assetequipment_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AssetEquipment }
     * 
     */
    public AssetEquipment createAssetEquipment() {
        return new AssetEquipment();
    }

    /**
     * Create an instance of {@link EquipmentBase }
     * 
     */
    public EquipmentBase createEquipmentBase() {
        return new EquipmentBase();
    }

    /**
     * Create an instance of {@link ChildAsset }
     * 
     */
    public ChildAsset createChildAsset() {
        return new ChildAsset();
    }

    /**
     * Create an instance of {@link ManufacturerInfo }
     * 
     */
    public ManufacturerInfo createManufacturerInfo() {
        return new ManufacturerInfo();
    }

    /**
     * Create an instance of {@link PartAssociation }
     * 
     */
    public PartAssociation createPartAssociation() {
        return new PartAssociation();
    }

    /**
     * Create an instance of {@link AssetEquipment.DORMANT }
     * 
     */
    public AssetEquipment.DORMANT createAssetEquipmentDORMANT() {
        return new AssetEquipment.DORMANT();
    }

    /**
     * Create an instance of {@link FleetVehicleInfo }
     * 
     */
    public FleetVehicleInfo createFleetVehicleInfo() {
        return new FleetVehicleInfo();
    }

    /**
     * Create an instance of {@link AssetEquipment.PurchaseOrderInfo }
     * 
     */
    public AssetEquipment.PurchaseOrderInfo createAssetEquipmentPurchaseOrderInfo() {
        return new AssetEquipment.PurchaseOrderInfo();
    }

    /**
     * Create an instance of {@link Variables }
     * 
     */
    public Variables createVariables() {
        return new Variables();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link AssetParentHierarchy }
     * 
     */
    public AssetParentHierarchy createAssetParentHierarchy() {
        return new AssetParentHierarchy();
    }

    /**
     * Create an instance of {@link AssetDependency }
     * 
     */
    public AssetDependency createAssetDependency() {
        return new AssetDependency();
    }

    /**
     * Create an instance of {@link PositionDependency }
     * 
     */
    public PositionDependency createPositionDependency() {
        return new PositionDependency();
    }

    /**
     * Create an instance of {@link PrimarySystemDependency }
     * 
     */
    public PrimarySystemDependency createPrimarySystemDependency() {
        return new PrimarySystemDependency();
    }

    /**
     * Create an instance of {@link SystemDependency }
     * 
     */
    public SystemDependency createSystemDependency() {
        return new SystemDependency();
    }

    /**
     * Create an instance of {@link LocationDependency }
     * 
     */
    public LocationDependency createLocationDependency() {
        return new LocationDependency();
    }

    /**
     * Create an instance of {@link NonDependentParents_Type }
     * 
     */
    public NonDependentParents_Type createNonDependentParents_Type() {
        return new NonDependentParents_Type();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link FacilityConditionIndex }
     * 
     */
    public FacilityConditionIndex createFacilityConditionIndex() {
        return new FacilityConditionIndex();
    }

    /**
     * Create an instance of {@link EnergyPerformance }
     * 
     */
    public EnergyPerformance createEnergyPerformance() {
        return new EnergyPerformance();
    }

    /**
     * Create an instance of {@link AssetEquipment.PERFORMANCEDETAILS }
     * 
     */
    public AssetEquipment.PERFORMANCEDETAILS createAssetEquipmentPERFORMANCEDETAILS() {
        return new AssetEquipment.PERFORMANCEDETAILS();
    }

    /**
     * Create an instance of {@link EquipmentHospitalityFacility }
     * 
     */
    public EquipmentHospitalityFacility createEquipmentHospitalityFacility() {
        return new EquipmentHospitalityFacility();
    }

    /**
     * Create an instance of {@link AssetChildHierarchy }
     * 
     */
    public AssetChildHierarchy createAssetChildHierarchy() {
        return new AssetChildHierarchy();
    }

    /**
     * Create an instance of {@link EquipmentCore }
     * 
     */
    public EquipmentCore createEquipmentCore() {
        return new EquipmentCore();
    }

    /**
     * Create an instance of {@link EquipmentHealthcareAsset }
     * 
     */
    public EquipmentHealthcareAsset createEquipmentHealthcareAsset() {
        return new EquipmentHealthcareAsset();
    }

    /**
     * Create an instance of {@link EquipmentHospitalityVehicle }
     * 
     */
    public EquipmentHospitalityVehicle createEquipmentHospitalityVehicle() {
        return new EquipmentHospitalityVehicle();
    }

    /**
     * Create an instance of {@link AllEquipment }
     * 
     */
    public AllEquipment createAllEquipment() {
        return new AllEquipment();
    }

    /**
     * Create an instance of {@link EquipmentBase.DORMANT }
     * 
     */
    public EquipmentBase.DORMANT createEquipmentBaseDORMANT() {
        return new EquipmentBase.DORMANT();
    }

    /**
     * Create an instance of {@link EquipmentBase.PurchaseOrderInfo }
     * 
     */
    public EquipmentBase.PurchaseOrderInfo createEquipmentBasePurchaseOrderInfo() {
        return new EquipmentBase.PurchaseOrderInfo();
    }

    /**
     * Create an instance of {@link EquipmentBase.PERFORMANCEDETAILS }
     * 
     */
    public EquipmentBase.PERFORMANCEDETAILS createEquipmentBasePERFORMANCEDETAILS() {
        return new EquipmentBase.PERFORMANCEDETAILS();
    }

    /**
     * Create an instance of {@link EquipmentHealthcareSystem }
     * 
     */
    public EquipmentHealthcareSystem createEquipmentHealthcareSystem() {
        return new EquipmentHealthcareSystem();
    }

    /**
     * Create an instance of {@link EquipmentHealthcareProperty }
     * 
     */
    public EquipmentHealthcareProperty createEquipmentHealthcareProperty() {
        return new EquipmentHealthcareProperty();
    }

    /**
     * Create an instance of {@link EquipmentHospitalityRoom }
     * 
     */
    public EquipmentHospitalityRoom createEquipmentHospitalityRoom() {
        return new EquipmentHospitalityRoom();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link NonDependentParents_Type }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/AssetEquipment_001", name = "NonDependentParents")
    public JAXBElement<NonDependentParents_Type> createNonDependentParents(NonDependentParents_Type value) {
        return new JAXBElement<NonDependentParents_Type>(_NonDependentParents_QNAME, NonDependentParents_Type.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/AssetEquipment_001", name = "NoParents")
    public JAXBElement<String> createNoParents(String value) {
        return new JAXBElement<String>(_NoParents_QNAME, String.class, null, value);
    }

}
